@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "python-mode" "6.3.1"
+(define-package "python-mode" "20250930.608"
   "Python major mode."
   ()
   :url "https://gitlab.com/groups/python-mode-devs"
-  :commit "fdd3b2eebaf496b52da7e385394e5408a57bea13"
-  :revdesc "6.3.1-0-gfdd3b2eebaf4"
+  :commit "5aaf8b386aa694429d997c6fd49772b0b359e514"
+  :revdesc "5aaf8b386aa6"
   :keywords '("python" "languages" "oop")
   :maintainers '((nil . "python-mode@python.org")))
